@@ -369,8 +369,8 @@ sending."
 I.e., either \"name <email>\" or \"email\". Return nil if not found.
 
 This function can be used for `completion-at-point-functions', to
-complete addresses. This can be used outside mu4e, but mu4e must
-be active (running) for this to work."
+complete addresses. This can be used from outside mu4e, but mu4e
+must be active (running) for this to work."
   (let* ((end (point))
          (start (save-excursion
                   (re-search-backward "\\(\\`\\|[\n:,]\\)[ \t]*")
@@ -526,6 +526,9 @@ message buffer."
   "Handler called with DOCID and PATH for the just-sent message.
 For Forwarded ('Passed') and Replied messages, try to set the
 appropriate flag at the message forwarded or replied-to."
+  ;; XXX we don't need this function anymore here, but
+  ;; we have an external caller in mu4e-icalendar... we should
+  ;; update that.
   (mu4e--set-parent-flags path)
   ;; if the draft file exists, remove it now.
   (when (file-exists-p path)
@@ -549,15 +552,23 @@ appropriate flag at the message forwarded or replied-to."
       (unless (message-fetch-field "In-Reply-To")
         (message-remove-header "References")))
     (when use-hard-newlines
-      (mu4e--send-harden-newlines)))
-  ;; for safety, always save the draft before sending
-  (set-buffer-modified-p t)
-  (save-buffer))
-
-(defun mu4e--compose-after-send ()
-  "Function called just after sending a message."
-  (setq mu4e-sent-func #'mu4e-sent-handler)
-  (mu4e--server-sent (buffer-file-name)))
+      (mu4e--send-harden-newlines))
+    ;; now handle what happens _after_ sending; typically, draft is gone and
+    ;; the sent message appears in sent. Update flags for related messages,
+    ;; i.e. for Forwarded ('Passed') and Replied messages, try to set the
+    ;; appropriate flag at the message forwarded or replied-to.
+    (add-hook 'message-sent-hook
+              (lambda ()
+                (save-restriction
+                  (message-narrow-to-headers)
+                  (when-let ((fcc-path (message-fetch-field "Fcc")))
+                    (mu4e--set-parent-flags fcc-path)
+                    ;; we end up with a ((buried) buffer here, visiting
+                    ;; the fcc-path; not quite sure why. But let's
+                    ;; get rid of it (#2681)
+                    (when-let ((buf (find-buffer-visiting fcc-path)))
+                      (kill-buffer buf)))))
+              nil t)))
 
 ;;; Crypto
 (defun mu4e--compose-setup-crypto (parent compose-type)
@@ -793,12 +804,11 @@ PARENT is the \"parent\" message; nil
       ;; annoyingly, various message- functions call `message-pop-to-buffer`
       ;; (showing the message. But we're not ready for that yet. So
       ;; temporarily override that.
-      (advice-add 'message-pop-to-buffer
-                  :override #'mu4e--fake-pop-to-buffer)
-      (funcall compose-func parent)
+      (cl-letf (((symbol-function #'message-pop-to-buffer)
+                  #'mu4e--fake-pop-to-buffer))
+        (funcall compose-func parent))
       ;; add some more headers, if needed.
       (message-generate-headers (mu4e--headers compose-type))
-      (advice-remove 'message-pop-to-buffer #'mu4e--fake-pop-to-buffer)
       (current-buffer)))) ;; returns new buffer (this is not the tmp buf)
 
 
@@ -842,7 +852,6 @@ replied to or forwarded, etc."
   (add-hook 'before-save-hook  #'mu4e--compose-before-save nil t)
   (add-hook 'after-save-hook   #'mu4e--compose-after-save nil t)
   (add-hook 'message-send-hook #'mu4e--compose-before-send nil t)
-  (add-hook 'message-sent-hook #'mu4e--compose-after-send nil t)
 
   (when-let ((fcc-path (mu4e--fcc-path (mu4e--message-basename) parent)))
     (message-add-header (concat "Fcc: " fcc-path "\n")))
@@ -1002,8 +1011,10 @@ must be from current user, as determined through
     (mu4e--compose-setup
      'edit
      (lambda (parent)
-       (find-file (plist-get parent :path))
-       (mu4e--delimit-headers)))))
+       (let ((buf (find-file-noselect (plist-get parent :path))))
+         (with-current-buffer buf
+           (mu4e--delimit-headers))
+         (switch-to-buffer buf))))))
 
 ;;;###autoload
 (defun mu4e-compose-resend (address)
